@@ -1,7 +1,7 @@
 
 library(testthat)
 library(caret)
-library(recipes)
+library(themis)
 
 context('upsampling with recipes')
 
@@ -14,7 +14,7 @@ dat <- twoClassSim(200, intercept = 6)
 
 rec <-
   recipe(Class ~ TwoFactor1 + TwoFactor2 + Linear01, data = dat) %>%
-  step_upsample(Class, seed = 534)
+  themis::step_upsample(Class, seed = 534)
 
 
 test_that("model test", {
